//
//  Firework+JsEvent.swift
//  react-native-firework-sdk
//
//  Created by Jeff on 2021/12/21.
//

import Foundation
import FireworkVideo

extension FireworkVideoSDKError {
    var jsErrorName: String {
        switch self {
        case .missingAppID:
            return "missingAppID"
        case .missingPublisherID:
            return "missingPublisherID"
        case .authenticationFailure:
            return "authenticationFailure"
        default:
            return "unknow"
        }
    }
}

extension VideoPlaybackDetails {
    var jsObject: [String: Any?] {
        [ "videoId": videoID,
         "duration": duration,
         "caption": caption,
         "badge": badge,
         "playerSize": ["width": playerSize.width,
                         "height": playerSize.height],
         "hasCTA": hasCTA]
    }
}

extension VideoFeedError {
    var jsObject: [String: String] {
        var error: [String: String]
        switch self {
        case .contentSourceError(let sourceError):
            error = ["name": "contentSourceError", "reason": sourceError.recoverySuggestion ?? "contentSourceError"]
        case .videoShareError(let shareError):
            error = ["name": "videoShareError", "reason": shareError.recoverySuggestion ?? "videoShareError"]
        case .unknownError(let unknownError):
            error = ["name": "unknownError", "reason": unknownError.localizedDescription]
        default:
            error = ["name": "unknownError", "reason": "unknownError"]
        }
        
        return error
    }
}

extension FeedEventDetails {
    var jsObject: [String: Any] {
        return ["index": index,
                "videoId": id,
                "duration": duration]
    }
}

//@todo
//extension LiveStreamEventDetails {
//    var jsObject: [String: Any] {
//        return ["id": id]
//    }
//}
//
//extension LiveStreamChatDetails {
//    var jsObject: [String: Any] {
//        return ["messageID": messageID,
//                "username": username,
//                "text": text]
//    }
//}
