import '../../models/video_player_configuration.dart';

class VideoPlayerConfigurationUtil {
  static String _convertToRawPlayerStyle(VideoPlayerStyle style) {
    String rawStyle = "";
    switch (style) {
      case VideoPlayerStyle.full:
        rawStyle = "full";
        break;
      case VideoPlayerStyle.fill:
        rawStyle = "fill";
        break;
    }

    return rawStyle;
  }

  static String _convertToRawPlayerCompleteAction(
      VideoPlayerCompleteAction action) {
    String rawAction = "";
    switch (action) {
      case VideoPlayerCompleteAction.loop:
        rawAction = "loop";
        break;
      case VideoPlayerCompleteAction.advanceToNext:
        rawAction = "advanceToNext";
        break;
    }
    return rawAction;
  }

  static Map<String, dynamic> _convertCTAStyleToJson(
      VideoPlayerCTAStyle ctaStyle) {
    Map<String, dynamic> json = {};
    if (ctaStyle.backgroundColor != null &&
        ctaStyle.backgroundColor!.isNotEmpty) {
      json["backgroundColor"] = ctaStyle.backgroundColor!;
    }

    if (ctaStyle.textColor != null && ctaStyle.textColor!.isNotEmpty) {
      json["textColor"] = ctaStyle.textColor!;
    }

    if (ctaStyle.fontSize != null) {
      json["fontSize"] = ctaStyle.fontSize!.toDouble();
    }

    return json;
  }

  static Map<String, dynamic> toJson(VideoPlayerConfiguration config) {
    Map<String, dynamic> json = {};

    if (config.playerStyle != null) {
      json["playerStyle"] = _convertToRawPlayerStyle(config.playerStyle!);
    }

    if (config.videoCompleteAction != null) {
      json["videoCompleteAction"] =
          _convertToRawPlayerCompleteAction(config.videoCompleteAction!);
    }

    if (config.showShareButton != null) {
      json["showShareButton"] = config.showShareButton!;
    }

    if (config.ctaButtonStyle != null) {
      json["ctaButtonStyle"] = _convertCTAStyleToJson(config.ctaButtonStyle!);
    }

    if (config.showPlaybackButton != null) {
      json["showPlaybackButton"] = config.showPlaybackButton!;
    }

    if (config.showMuteButton != null) {
      json["showMuteButton"] = config.showMuteButton!;
    }

    return json;
  }
}
